% silicon band structure
% based on http://www.ece.nus.edu.sg/stfpage/eleadj/pseudopotential.htm

n = 5;
s = 0.01;

init(n);

L = [1/2;1/2;1/2];
G = [0;0;0];
X = [1;0;0];
W = [1;0;1/2];
K = [3/4;0;3/4];

v = 0;
x = [];
y = [];
Lx = 0;

[n,k,e] = part(L,G,s); x = [x;k+v]; y = [y;e]; v = v+n; G1x = v;
[n,k,e] = part(G,X,s); x = [x;k+v]; y = [y;e]; v = v+n; Xx = v;
[n,k,e] = part(X,W,s); x = [x;k+v]; y = [y;e]; v = v+n; Wx = v;
[n,k,e] = part(W,K,s); x = [x;k+v]; y = [y;e]; v = v+n; Kx = v;
[n,k,e] = part(K,G,s); x = [x;k+v]; y = [y;e]; v = v+n; G2x = v;
e = energy(G); x = [x;v]; y = [y;e'];

eg = e(4);
ymin=min(min(y))-eg;
ymax=max(max(y))-eg;

hold on;
title("Silicon band structure");
xlabel("k [2π/a]");
ylabel("E [eV]");
plot(x,y-eg,'k');
plot([G1x,G1x],[ymin,ymax],'b');
plot([Xx,Xx],[ymin,ymax],'b');
plot([Wx,Wx],[ymin,ymax],'b');
plot([Kx,Kx],[ymin,ymax],'b');
set (gca,'xtick',[Lx G1x Xx Wx Kx G2x]);
set (gca,'xticklabel',{"L","Γ","X","W","K","Γ"});
axis([0 v -6 6]);
hold off;

print("band.png");
